@@ -1,10 +1,11 @@
-class Excercise:
+
+class Exercise:
     def __init__(self, exc):
         '''
-        This class manages the state of the excercise.
+        This class manages the state of the exercise.
 
         Args:
-            exc(int): Excercise (ÜB), example: 1
+            exc(int): exercise (ÜB), example: 1
             task(str): Task (Aufgabe), example: 2
             subtask(str): Subtask(Teilaufgabe), example: a
         '''
@@ -44,7 +45,7 @@ class Task:
         This class manages the state of the task.
 
         Args:
-            exc(int): Excercise (ÜB), example: 1
+            exc(int): exercise (ÜB), example: 1
             task(str): Task (Aufgabe), example: 2
             points(float): Points (Punkte), example: 2
         '''
@@ -97,7 +98,7 @@ class SubTask:
         This class manages the state of the subtask.
 
         Args:
-            exc(int): Excercise (ÜB), example: 1
+            exc(int): exercise (ÜB), example: 1
             subtask(str): Subtask (Teilaufgabe), example: 1.2
             points(float): Points (Punkte), example: 2
         '''        
@@ -133,4 +134,8 @@ class SubTask:
         return self.data
     
     def setData(self, data):
-        self.data = data
\ No newline at end of file
+        self.data = data
+
+# Spätere Features:
+#   def getScaledPoints(self):
+#   def autograde(self):
