@@ -50,8 +50,8 @@ class Util:
                            partial_score_points):
         score = 0
         try:
-            solution = {k: Util.str_sanitize(v) for k, v in solution.items()}
-            student_dict = {k: Util.str_sanitize(v) for k, v in student_dict.items()}
+            solution = {Util.str_sanitize(k): v for k, v in solution.items()}
+            student_dict = {Util.str_sanitize(k): v for k, v in student_dict.items()}
             # check for exact match
             for x in solution:
                 print("checking columns: ", x, " | ", solution[x])
